@@ -34,3 +34,22 @@ class AwsSimulator(StrangeworksBackend):
             account_details=account_details,
             **fields,
         )
+
+
+class GeneralAWSBackend(StrangeworksBackend):
+    @classmethod
+    def _default_options(cls):
+        return Options()
+
+    def __init__(
+        self, configuration, provider, name, client, remote, account_details, **fields
+    ):
+        super().__init__(
+            configuration=configuration,
+            provider=provider,
+            name=name,
+            client=client,
+            remote=remote,
+            account_details=account_details,
+            **fields,
+        )
