@@ -1,6 +1,6 @@
 import strangeworks
 
-import time
+import time, json
 
 from abc import ABC
 
@@ -158,11 +158,6 @@ class _SWRemoteJob(_SWJob):
 
     # assumes your Job.Status is in a JOB_FINAL_STATE
     def _get_result(self, response):
-        if self._status == JobStatus.ERROR:
-            raise StrangeworksError(
-                f"Unable to get a result from an errored job {self.job_id()}"
-            )
-
         if self._status == JobStatus.CANCELLED:
             raise StrangeworksError(
                 f"Unable to get a result from a cancelled job {self.job_id()}"
@@ -182,7 +177,16 @@ class _SWRemoteJob(_SWJob):
         if "job_zip_url" in response:
             self._result_url = response["job_zip_url"]
 
-        return Result.from_dict(result["data"])
+        data = result["data"]
+
+        if self._status == JobStatus.ERROR:
+            raise StrangeworksError(
+                f"Unable to get a result from an errored job {self.job_id()}\n{data}"
+            )
+
+        res = json.loads(data)
+
+        return Result.from_dict(res)
 
     @classmethod
     def get_job(cls, job_id: str) -> "_SWRemoteJob":
